"""
    domonic.webapi
    ====================================

    home to all the webapi modules

"""

# DONT DO THIS...
# from .encoding import *
# from .fetch import *
# from .url import *
